import { useState } from "react";
import Card from "@/Components/Card";
import ImgIcon from "@/Components/ImgIcon";
import Connection from "./Connection";
import ButtonSm from "@/Components/Buttons/ButtonSm";
import DeleteButton from "@/Components/Buttons/DeleteButton";
import { useForm } from '@inertiajs/react';
import toast, { Toaster } from 'react-hot-toast';
import QrCode from "./QrCode";
import DisconnectButton from "./DisconnectButton";
import ToggleSwitch from "./ToggleSwitch";

export default function CardInstance({ instance, handleRequest }) {
    const { post: qrCodePost, processing: qrCodeProcessing } = useForm({ id: instance?.id });
    const { post: disconnectPost, processing: disconnectProcessing } = useForm({ id: instance?.id });
    const { post: deletePost, processing: deleteProcessing } = useForm({ id: instance?.id, _method: 'DELETE' });

    // Gerar QrCode
    const instanceQrCode = (e) => {
        e.preventDefault();
        handleRequest(qrCodePost, route('whatsapp.connect', instance?.id), 'QrCode gerado com sucesso!');
    };

    // Desconectar instância
    const instanceDisconnect = (e) => {
        e.preventDefault();
        handleRequest(disconnectPost, route('whatsapp.disconnect', instance?.id), 'Instância desconectada com sucesso!');
    };

    // Deletar instância
    const instanceDelete = (e) => {
        e.preventDefault();
        handleRequest(deletePost, route('whatsapp.destroy', instance?.id), 'Instância excluída com sucesso!');
    };

    // Estado para controlar modal delete
    const [isModalDeleteOpen, setIsModalDeleteOpen] = useState(false);
    const handleModalDelete = () => { setIsModalDeleteOpen(true) };
    const handleCloseModalDelete = () => { setIsModalDeleteOpen(false) };

    return (
        <Card className="p-4">
            <Toaster />
            <div className="flex justify-start items-center mb-3">
                {instance?.picture && <ImgIcon img={instance?.picture} />}
                {!instance?.picture && <i className="bi bi-person-circle text-3xl"></i>}

                <div className="ms-3">
                    <p className="text-[.8rem] font-semibold text-text-white">{instance?.name}</p>
                    <p className="text-[.65rem] text-text-primary">{instance?.whats_number}</p>
                </div>
            </div>

            <Connection connection={instance?.connection} />

            {instance?.connection !== 'open' && instance?.qr_code && <QrCode instance={instance} />}

            <ToggleSwitch instance={instance} />

            <div className="flex justify-between items-center border-t border-t-border mt-4 pt-3">
                {instance?.connection === 'open' ? (
                    <DisconnectButton onDelete={instanceDisconnect} disabled={disconnectProcessing} />
                ) : (
                    <ButtonSm disabled={qrCodeProcessing} onClick={instanceQrCode} actionTitle='Gerando QrCode...'>
                        <p className="text-text-white me-2">Gerar QrCode</p> <i className="bi bi-qr-code-scan"></i>
                    </ButtonSm>
                )}

                <DeleteButton
                    onDelete={instanceDelete}
                    disabled={deleteProcessing}
                    isOpen={isModalDeleteOpen}
                    openModal={handleModalDelete}
                    closeModal={handleCloseModalDelete}
                />
            </div>
        </Card>
    );
}
